@@ -1,5 +1,6 @@
 """uses opencv to read frames from video."""
 import cv2
+import time
 import numpy as np
 import random
 
@@ -8,12 +9,12 @@ from .shared_queue import SharedQueue
 from .utils import handle_url
 
 
-def read_vids(vids, worker_id, take_every_nth, resize_size, batch_size, queue_export):
+def read_vids(vid_refs, worker_id, take_every_nth, resize_size, batch_size, queue_export):
     """
     Reads list of videos, saves frames to Shared Queue
 
     Input:
-      vids - list of videos (either path or youtube link)
+      vid_refs - list of videos (either path or youtube link) and their references
       worker_id - unique ID of worker
       take_every_nth - offset between frames of video (to lower FPS)
       resize_size - new pixel height and width of resized frame
@@ -21,8 +22,10 @@ def read_vids(vids, worker_id, take_every_nth, resize_size, batch_size, queue_ex
       queue_export - SharedQueue export used re-create SharedQueue object in worker
     """
     queue = SharedQueue.from_export(*queue_export)
+    t0 = time.perf_counter()
+    print(f"Worker #{worker_id} starting processing {len(vid_refs)} videos")
 
-    def get_frames(vid):
+    def get_frames(vid, ref):
         # TODO: better way of testing if vid is url
         if vid.startswith("http://") or vid.startswith("https://"):
             load_vid, file, dst_name = handle_url(vid)
@@ -52,6 +55,10 @@ def read_vids(vids, worker_id, take_every_nth, resize_size, batch_size, queue_ex
                 video_frames.append(frame)
             ind += 1
 
+        if len(video_frames) == 0:
+            print(f"Warning: {vid} contained 0 frames")
+            return
+
         np_frames = np.array(video_frames)
         f_ct = np_frames.shape[0]
         pad_by = 0
@@ -61,6 +68,7 @@ def read_vids(vids, worker_id, take_every_nth, resize_size, batch_size, queue_ex
             np_frames = np_frames.reshape((-1, batch_size, resize_size, resize_size, 3))
 
         info = {
+            "reference": ref,
             "dst_name": dst_name,
             "pad_by": pad_by,
         }
@@ -69,9 +77,11 @@ def read_vids(vids, worker_id, take_every_nth, resize_size, batch_size, queue_ex
         if file is not None:  # for python files that need to be closed
             file.close()
 
-    random.Random(worker_id).shuffle(vids)
-    for vid in vids:
+    random.Random(worker_id).shuffle(vid_refs)
+    for vid, ref in vid_refs:
         try:
-            get_frames(vid)
-        except:  # pylint: disable=bare-except
-            print(f"Error: Video {vid} failed")
+            get_frames(vid, ref)
+        except Exception as e:  # pylint: disable=broad-except
+            print(f"Error: Video {vid} failed with message - {e}")
+    tf = time.perf_counter()
+    print(f"Worker #{worker_id} done processing {len(vid_refs)} videos in {tf-t0}[s]")
